# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM签名/鉴权错误。
AUTHFAILURE = 'AuthFailure'

# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 该域名已在您的列表中，无需重复添加。
FAILEDOPERATION_DOMAINEXISTS = 'FailedOperation.DomainExists'

# 该域名为腾讯云 DNSPod 重点保护资源，为了避免误操作造成的业务影响，域名禁止自行操作删除。如果您确认需要删除域名，请先联系您的客户经理，我们将竭诚为您提供技术支持。
FAILEDOPERATION_DOMAINISKEYDOMAIN = 'FailedOperation.DomainIsKeyDomain'

# 锁定域名不能进行此操作。
FAILEDOPERATION_DOMAINISLOCKED = 'FailedOperation.DomainIsLocked'

# 封禁域名不能进行此操作。
FAILEDOPERATION_DOMAINISSPAM = 'FailedOperation.DomainIsSpam'

# VIP域名不能进行此操作。
FAILEDOPERATION_DOMAINISVIP = 'FailedOperation.DomainIsVip'

# 该域名已被其他账号添加，可在域名列表中添加取回。
FAILEDOPERATION_DOMAINOWNEDBYOTHERUSER = 'FailedOperation.DomainOwnedByOtherUser'

# 帐号异地登录，请求被拒绝。
FAILEDOPERATION_LOGINAREANOTALLOWED = 'FailedOperation.LoginAreaNotAllowed'

# 登录失败，请检查账号和密码是否正确。
FAILEDOPERATION_LOGINFAILED = 'FailedOperation.LoginFailed'

# 权限错误，您无法查看该任务的详情。
FAILEDOPERATION_NOTBATCHTASKOWNER = 'FailedOperation.NotBatchTaskOwner'

# 域名不在您的名下。
FAILEDOPERATION_NOTDOMAINOWNER = 'FailedOperation.NotDomainOwner'

# 未实名认证用户，请先完成实名认证再操作。
FAILEDOPERATION_NOTREALNAMEDUSER = 'FailedOperation.NotRealNamedUser'

# 不能转移到企业账号。
FAILEDOPERATION_TRANSFERTOENTERPRISEDENIED = 'FailedOperation.TransferToEnterpriseDenied'

# 不能转移到个人账号。
FAILEDOPERATION_TRANSFERTOPERSONDENIED = 'FailedOperation.TransferToPersonDenied'

# 操作未响应，请稍后重试。
FAILEDOPERATION_UNKNOWERROR = 'FailedOperation.UnknowError'

# 内部错误。
INTERNALERROR = 'InternalError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 您的账号已被系统封禁，如果您有任何疑问请与我们联系。
INVALIDPARAMETER_ACCOUNTISBANNED = 'InvalidParameter.AccountIsBanned'

# 创建批量域名任务失败，原因：内部错误。
INVALIDPARAMETER_BATCHDOMAINCREATEACTIONERROR = 'InvalidParameter.BatchDomainCreateActionError'

# 创建批量记录任务失败，原因：内部错误。
INVALIDPARAMETER_BATCHRECORDCREATEACTIONERROR = 'InvalidParameter.BatchRecordCreateActionError'

# 批量修改记录任务失败，原因：内部错误。
INVALIDPARAMETER_BATCHRECORDMODIFYACTIONERROR = 'InvalidParameter.BatchRecordModifyActionError'

# 记录值无效。
INVALIDPARAMETER_BATCHRECORDMODIFYACTIONINVALIDVALUE = 'InvalidParameter.BatchRecordModifyActionInvalidValue'

# 批量替换记录任务失败，原因：内部错误。
INVALIDPARAMETER_BATCHRECORDREPLACEACTIONERROR = 'InvalidParameter.BatchRecordReplaceActionError'

# 超过批量任务数上限。
INVALIDPARAMETER_BATCHTASKCOUNTLIMIT = 'InvalidParameter.BatchTaskCountLimit'

# 任务不存在，无法获取任务详情。
INVALIDPARAMETER_BATCHTASKNOTEXIST = 'InvalidParameter.BatchTaskNotExist'

# 自定义错误信息。
INVALIDPARAMETER_CUSTOMMESSAGE = 'InvalidParameter.CustomMessage'

# 该域名开启了 DNSSEC，不允许添加 @ 子域名 CNAME、显性 URL 或者隐性 URL 记录。
INVALIDPARAMETER_DNSSECADDCNAMEERROR = 'InvalidParameter.DnssecAddCnameError'

# 别名已经存在。
INVALIDPARAMETER_DOMAINALIASEXISTS = 'InvalidParameter.DomainAliasExists'

# 别名编号错误。
INVALIDPARAMETER_DOMAINALIASIDINVALID = 'InvalidParameter.DomainAliasIdInvalid'

# 域名编号不正确。
INVALIDPARAMETER_DOMAINIDINVALID = 'InvalidParameter.DomainIdInvalid'

# 不允许操作生效中或失效中的域名。
INVALIDPARAMETER_DOMAININEFFECTORINVALIDATED = 'InvalidParameter.DomainInEffectOrInvalidated'

# 域名不正确，请输入主域名，如 dnspod.cn。
INVALIDPARAMETER_DOMAININVALID = 'InvalidParameter.DomainInvalid'

# 此域名是其它域名的别名。
INVALIDPARAMETER_DOMAINISALIASER = 'InvalidParameter.DomainIsAliaser'

# 域名没有锁定。
INVALIDPARAMETER_DOMAINISNOTLOCKED = 'InvalidParameter.DomainIsNotlocked'

# 暂停域名不支持锁定。
INVALIDPARAMETER_DOMAINNOTALLOWEDLOCK = 'InvalidParameter.DomainNotAllowedLock'

# 处于生效中/失效中的域名，不允许变更解析记录。
INVALIDPARAMETER_DOMAINNOTALLOWEDMODIFYRECORDS = 'InvalidParameter.DomainNotAllowedModifyRecords'

# 该域名未备案，无法添加 URL 记录。
INVALIDPARAMETER_DOMAINNOTBEIAN = 'InvalidParameter.DomainNotBeian'

# 域名还没有注册，无法添加。
INVALIDPARAMETER_DOMAINNOTREGED = 'InvalidParameter.DomainNotReged'

# 记录已经存在，无需再次添加。
INVALIDPARAMETER_DOMAINRECORDEXIST = 'InvalidParameter.DomainRecordExist'

# 域名自己无需进行复制。
INVALIDPARAMETER_DOMAINSELFNOCOPY = 'InvalidParameter.DomainSelfNoCopy'

# 没有提交任何域名。
INVALIDPARAMETER_DOMAINSEMPTY = 'InvalidParameter.DomainsEmpty'

# 邮箱地址不正确。
INVALIDPARAMETER_EMAILINVALID = 'InvalidParameter.EmailInvalid'

# 抱歉，您的账户还没有通过邮箱验证。
INVALIDPARAMETER_EMAILNOTVERIFIED = 'InvalidParameter.EmailNotVerified'

# 请输入合法的邮箱或者uin。
INVALIDPARAMETER_EMAILORQQINVALID = 'InvalidParameter.EmailOrQqInvalid'

# 域名已经在该账号下。
INVALIDPARAMETER_EMAILSAME = 'InvalidParameter.EmailSame'

# 分组编号不正确。
INVALIDPARAMETER_GROUPIDINVALID = 'InvalidParameter.GroupIdInvalid'

# 同名分组已经存在。
INVALIDPARAMETER_GROUPNAMEEXISTS = 'InvalidParameter.GroupNameExists'

# 分组名为1-17个字符。
INVALIDPARAMETER_GROUPNAMEINVALID = 'InvalidParameter.GroupNameInvalid'

# 权重不合法。请输入0~100的整数。
INVALIDPARAMETER_INVALIDWEIGHT = 'InvalidParameter.InvalidWeight'

# 单次任务数量超过上限。
INVALIDPARAMETER_JOBGREATERTHANLIMIT = 'InvalidParameter.JobGreaterThanLimit'

# 锁定天数不正确。
INVALIDPARAMETER_LOCKDAYSINVALID = 'InvalidParameter.LockDaysInvalid'

# Token 的 ID 不正确。
INVALIDPARAMETER_LOGINTOKENIDERROR = 'InvalidParameter.LoginTokenIdError'

# 传入的 Token 不存在。
INVALIDPARAMETER_LOGINTOKENNOTEXISTS = 'InvalidParameter.LoginTokenNotExists'

# Token 验证失败。
INVALIDPARAMETER_LOGINTOKENVALIDATEFAILED = 'InvalidParameter.LoginTokenValidateFailed'

# 抱歉，您的账户还没有通过手机验证。
INVALIDPARAMETER_MOBILENOTVERIFIED = 'InvalidParameter.MobileNotVerified'

# MX优先级不正确。
INVALIDPARAMETER_MXINVALID = 'InvalidParameter.MxInvalid'

# 分页起始数量错误。
INVALIDPARAMETER_OFFSETINVALID = 'InvalidParameter.OffsetInvalid'

# 操作失败，请稍候再试。
INVALIDPARAMETER_OPERATEFAILED = 'InvalidParameter.OperateFailed'

# 对方账号未实名认证，请先完成实名认证再操作。
INVALIDPARAMETER_OTHERACCOUNTUNREALNAME = 'InvalidParameter.OtherAccountUnrealName'

# param 格式错误。
INVALIDPARAMETER_PARAMINVALID = 'InvalidParameter.ParamInvalid'

# 参数不合法，请求被拒绝。
INVALIDPARAMETER_PARAMSILLEGAL = 'InvalidParameter.ParamsIllegal'

# 参数错误。
INVALIDPARAMETER_PARAMSMISSING = 'InvalidParameter.ParamsMissing'

# 用户UIN无效。
INVALIDPARAMETER_QCLOUDUININVALID = 'InvalidParameter.QcloudUinInvalid'

# 记录编号错误。
INVALIDPARAMETER_RECORDIDINVALID = 'InvalidParameter.RecordIdInvalid'

# 记录线路不正确。
INVALIDPARAMETER_RECORDLINEINVALID = 'InvalidParameter.RecordLineInvalid'

# 记录类型不正确。
INVALIDPARAMETER_RECORDTYPEINVALID = 'InvalidParameter.RecordTypeInvalid'

# 记录的值不正确。
INVALIDPARAMETER_RECORDVALUEINVALID = 'InvalidParameter.RecordValueInvalid'

# 解析记录值过长。
INVALIDPARAMETER_RECORDVALUELENGTHINVALID = 'InvalidParameter.RecordValueLengthInvalid'

# 没有提交任何记录。
INVALIDPARAMETER_RECORDSEMPTY = 'InvalidParameter.RecordsEmpty'

# 备注信息超出字符限制。
INVALIDPARAMETER_REMARKLENGTHEXCEEDED = 'InvalidParameter.RemarkLengthExceeded'

# 备注过长（不能超过200个字）。
INVALIDPARAMETER_REMARKTOOLONG = 'InvalidParameter.RemarkTooLong'

# 您的IP非法，请求被拒绝。
INVALIDPARAMETER_REQUESTIPLIMITED = 'InvalidParameter.RequestIpLimited'

# 搜索结果大于500条，请增加关键字。
INVALIDPARAMETER_RESULTMORETHAN500 = 'InvalidParameter.ResultMoreThan500'

# 状态代码不正确。
INVALIDPARAMETER_STATUSCODEINVALID = 'InvalidParameter.StatusCodeInvalid'

# 子域名不正确。
INVALIDPARAMETER_SUBDOMAININVALID = 'InvalidParameter.SubdomainInvalid'

# 当前帐号下的无效域名过多，暂时无法使用该功能。请将已有域名的 DNS 服务器正确指向 DNSPod 之后，再尝试添加。
INVALIDPARAMETER_TOOMANYINVALIDDOMAINS = 'InvalidParameter.TooManyInvalidDomains'

# 域名无效。
INVALIDPARAMETER_TOOLSDOMAININVALID = 'InvalidParameter.ToolsDomainInvalid'

# 解锁代码已失效。
INVALIDPARAMETER_UNLOCKCODEEXPIRED = 'InvalidParameter.UnLockCodeExpired'

# 解锁代码不正确。
INVALIDPARAMETER_UNLOCKCODEINVALID = 'InvalidParameter.UnLockCodeInvalid'

# 未实名认证用户，请先完成实名认证再操作。
INVALIDPARAMETER_UNREALNAMEUSER = 'InvalidParameter.UnrealNameUser'

# 很抱歉，您要添加的URL的内容不符合DNSPod解析服务条款，URL添加/启用失败，如需帮助请联系技术支持。
INVALIDPARAMETER_URLVALUEILLEGAL = 'InvalidParameter.UrlValueIllegal'

# 用户不存在。
INVALIDPARAMETER_USERNOTEXISTS = 'InvalidParameter.UserNotExists'

# 域名等级不正确。
INVALIDPARAMETERVALUE_DOMAINGRADEINVALID = 'InvalidParameterValue.DomainGradeInvalid'

# 当前域名有误，请返回重新操作。
INVALIDPARAMETERVALUE_DOMAINNOTEXISTS = 'InvalidParameterValue.DomainNotExists'

# 分页长度数量错误。
INVALIDPARAMETERVALUE_LIMITINVALID = 'InvalidParameterValue.LimitInvalid'

# 用户编号不正确。
INVALIDPARAMETERVALUE_USERIDINVALID = 'InvalidParameterValue.UserIdInvalid'

# AAAA记录数量超出限制。
LIMITEXCEEDED_AAAACOUNTLIMIT = 'LimitExceeded.AAAACountLimit'

# @的NS记录只能设置为默认线路。
LIMITEXCEEDED_ATNSRECORDLIMIT = 'LimitExceeded.AtNsRecordLimit'

# 别名数量已经达到限制。
LIMITEXCEEDED_DOMAINALIASCOUNTEXCEEDED = 'LimitExceeded.DomainAliasCountExceeded'

# 当前绑定别名数量已达到限制。
LIMITEXCEEDED_DOMAINALIASNUMBERLIMIT = 'LimitExceeded.DomainAliasNumberLimit'

# 登录失败次数过多已被系统封禁。
LIMITEXCEEDED_FAILEDLOGINLIMITEXCEEDED = 'LimitExceeded.FailedLoginLimitExceeded'

# 已经达到最大分组数量限制。
LIMITEXCEEDED_GROUPNUMBERLIMIT = 'LimitExceeded.GroupNumberLimit'

# 该域名使用的套餐不支持隐性URL转发或数量已达上限，如需要使用，请去商城购买。
LIMITEXCEEDED_HIDDENURLEXCEEDED = 'LimitExceeded.HiddenUrlExceeded'

# NS记录数量超出限制。
LIMITEXCEEDED_NSCOUNTLIMIT = 'LimitExceeded.NsCountLimit'

# 记录的TTL值超出了限制。
LIMITEXCEEDED_RECORDTTLLIMIT = 'LimitExceeded.RecordTtlLimit'

# SRV记录数量超出限制。
LIMITEXCEEDED_SRVCOUNTLIMIT = 'LimitExceeded.SrvCountLimit'

# 子域名级数超出限制。
LIMITEXCEEDED_SUBDOMAINLEVELLIMIT = 'LimitExceeded.SubdomainLevelLimit'

# 子域名负载均衡数量超出限制。
LIMITEXCEEDED_SUBDOMAINROLLLIMIT = 'LimitExceeded.SubdomainRollLimit'

# 泛解析级数超出限制。
LIMITEXCEEDED_SUBDOMAINWCARDLIMIT = 'LimitExceeded.SubdomainWcardLimit'

# 该域名的显性URL转发数量已达上限，如需继续使用，请去商城购买。
LIMITEXCEEDED_URLCOUNTLIMIT = 'LimitExceeded.UrlCountLimit'

# 缺少参数错误。
MISSINGPARAMETER = 'MissingParameter'

# 您没有权限执行此操作。
OPERATIONDENIED_ACCESSDENIED = 'OperationDenied.AccessDenied'

# 仅域名所有者可进行此操作。
OPERATIONDENIED_DOMAINOWNERALLOWEDONLY = 'OperationDenied.DomainOwnerAllowedOnly'

# 抱歉，不允许添加黑名单中的IP。
OPERATIONDENIED_IPINBLACKLISTNOTALLOWED = 'OperationDenied.IPInBlacklistNotAllowed'

# 当前域名无权限，请返回域名列表。
OPERATIONDENIED_NOPERMISSIONTOOPERATEDOMAIN = 'OperationDenied.NoPermissionToOperateDomain'

# 您不是管理用户。
OPERATIONDENIED_NOTADMIN = 'OperationDenied.NotAdmin'

# 您不是代理用户。
OPERATIONDENIED_NOTAGENT = 'OperationDenied.NotAgent'

# 不是您名下用户。
OPERATIONDENIED_NOTMANAGEDUSER = 'OperationDenied.NotManagedUser'

# 请求的次数超过了频率限制。
REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'

# 您的IP添加了过多任务，请稍后重试。
REQUESTLIMITEXCEEDED_BATCHTASKLIMIT = 'RequestLimitExceeded.BatchTaskLimit'

# 您的帐号在短时间内添加了大量的域名，请控制添加频率。
REQUESTLIMITEXCEEDED_CREATEDOMAINLIMIT = 'RequestLimitExceeded.CreateDomainLimit'

# API请求次数超出限制。
REQUESTLIMITEXCEEDED_REQUESTLIMITEXCEEDED = 'RequestLimitExceeded.RequestLimitExceeded'

# 资源不存在。
RESOURCENOTFOUND = 'ResourceNotFound'

# 记录列表为空。
RESOURCENOTFOUND_NODATAOFRECORD = 'ResourceNotFound.NoDataOfRecord'

# 未授权操作。
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 黑名单更新出错。
FAILEDOPERATION_APPLYBLACKLISTDATAERROR = 'FailedOperation.ApplyBlackListDataError'

# 提交黑名单出错。
FAILEDOPERATION_APPLYBLACKLISTERROR = 'FailedOperation.ApplyBlackListError'

# 提交信审申请出错。
FAILEDOPERATION_APPLYCREDITAUDITERROR = 'FailedOperation.ApplyCreditAuditError'

# 机器人任务作业状态更新出错。
FAILEDOPERATION_CHANGEBOTCALLSTATUSERROR = 'FailedOperation.ChangeBotCallStatusError'

# 机器人任务状态更新出错。
FAILEDOPERATION_CHANGEBOTSTATUSERROR = 'FailedOperation.ChangeBotStatusError'

# 创建机器人任务出错。
FAILEDOPERATION_CREATEBOTTASKERROR = 'FailedOperation.CreateBotTaskError'

# 获取黑名单数据列表出错。
FAILEDOPERATION_DESCRIBEBLACKLISTDATAERROR = 'FailedOperation.DescribeBlacklistDataError'

# 查询机器人对话流出错。
FAILEDOPERATION_DESCRIBEBOTFLOWERROR = 'FailedOperation.DescribeBotFlowError'

# 查询机器人文件模板出错。
FAILEDOPERATION_DESCRIBEFILEMODELERROR = 'FailedOperation.DescribeFileModelError'

# 获取产品列表出错。
FAILEDOPERATION_DESCRIBEPRODUCTSERROR = 'FailedOperation.DescribeProductsError'

# 获取录音列表出错。
FAILEDOPERATION_DESCRIBERECORDSERROR = 'FailedOperation.DescribeRecordsError'

# 查询任务状态出错。
FAILEDOPERATION_DESCRIBETASKSTATUSERROR = 'FailedOperation.DescribeTaskStatusError'

# 录音列表下载出错。
FAILEDOPERATION_DOWNLOADRECORDLISTERROR = 'FailedOperation.DownloadRecordListError'

# 报告下载出错。
FAILEDOPERATION_DOWNLOADREPORTERROR = 'FailedOperation.DownloadReportError'

# 导出机器人数据失败。
FAILEDOPERATION_EXPORTBOTDATAERROR = 'FailedOperation.ExportBotDataError'

# 获取信审结果出错。
FAILEDOPERATION_GETCREDITAUDITERROR = 'FailedOperation.GetCreditAuditError'

# 查询黑名单出错。
FAILEDOPERATION_QUERYBLACKLISTDATAERROR = 'FailedOperation.QueryBlackListDataError'

# 查询机器人列表出错。
FAILEDOPERATION_QUERYBOTLISTERROR = 'FailedOperation.QueryBotListError'

# 查询任务失败。
FAILEDOPERATION_QUERYCALLLISTERROR = 'FailedOperation.QueryCallListError'

# 查询录音列表出错。
FAILEDOPERATION_QUERYRECORDLISTERROR = 'FailedOperation.QueryRecordListError'

# 修改机器人任务出错。
FAILEDOPERATION_UPDATEBOTTASKERROR = 'FailedOperation.UpdateBotTaskError'

# 上传机器人文件出错。
FAILEDOPERATION_UPLOADBOTFILE = 'FailedOperation.UploadBotFile'

# 上传数据出错。
FAILEDOPERATION_UPLOADDATAERROR = 'FailedOperation.UploadDataError'

# 内部错误。
INTERNALERROR = 'InternalError'

# 内部未知错误。
INTERNALERROR_UNKNOWNERROR = 'InternalError.UnknownError'

# 找不到Module 或 Operation。
MISSINGPARAMETER_MOERROR = 'MissingParameter.MOError'

# 黑名单数据不存在。
RESOURCENOTFOUND_BLACKLISTDATANOTFOUND = 'ResourceNotFound.BlacklistDataNotFound'

# 企业不存在。
RESOURCENOTFOUND_COMPANYNOTFOUND = 'ResourceNotFound.CompanyNotFound'

# 录音列表不存在。
RESOURCENOTFOUND_RECORDLISTNOTFOUND = 'ResourceNotFound.RecordListNotFound'

# 报告不存在。
RESOURCENOTFOUND_REPORTNOTFOUND = 'ResourceNotFound.ReportNotFound'

# 任务不存在。
RESOURCENOTFOUND_TASKNOTFOUND = 'ResourceNotFound.TaskNotFound'

# 企业已欠费或已被回收。
RESOURCEUNAVAILABLE_COMPANYUNAVAILABLE = 'ResourceUnavailable.CompanyUnavailable'

# 账户不存在或未开通金融联络机器人。
UNAUTHORIZEDOPERATION_ACCOUNTNOTFOUND = 'UnauthorizedOperation.AccountNotFound'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class AccessLogConfig(AbstractModel):
    """AccessLog 配置

    """

    def __init__(self):
        r"""
        :param Enable: 是否启用
        :type Enable: bool
        :param Template: 采用的模板，可选值：istio（默认）、trace
        :type Template: str
        :param SelectedRange: 选中的范围
        :type SelectedRange: :class:`tencentcloud.tcm.v20210413.models.SelectedRange`
        :param CLS: 腾讯云日志服务相关参数
        :type CLS: :class:`tencentcloud.tcm.v20210413.models.CLS`
        """
        self.Enable = None
        self.Template = None
        self.SelectedRange = None
        self.CLS = None


    def _deserialize(self, params):
        self.Enable = params.get("Enable")
        self.Template = params.get("Template")
        if params.get("SelectedRange") is not None:
            self.SelectedRange = SelectedRange()
            self.SelectedRange._deserialize(params.get("SelectedRange"))
        if params.get("CLS") is not None:
            self.CLS = CLS()
            self.CLS._deserialize(params.get("CLS"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ActiveOperation(AbstractModel):
    """正在执行的异步操作

    """

    def __init__(self):
        r"""
        :param OperationId: 操作Id
        :type OperationId: str
        :param Type: 操作类型，取值范围：
- LINK_CLUSTERS: 关联集群
- RELINK_CLUSTERS: 重新关联集群
- UNLINK_CLUSTERS: 解关联集群
- INSTALL_MESH: 安装网格
        :type Type: str
        """
        self.OperationId = None
        self.Type = None


    def _deserialize(self, params):
        self.OperationId = params.get("OperationId")
        self.Type = params.get("Type")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class AutoInjectionNamespaceState(AbstractModel):
    """描述某一网格在特定命名空间下的自动注入状态

    """

    def __init__(self):
        r"""
        :param Namespace: 命名空间名称
        :type Namespace: str
        :param State: 注入状态
注意：此字段可能返回 null，表示取不到有效值。
        :type State: str
        """
        self.Namespace = None
        self.State = None


    def _deserialize(self, params):
        self.Namespace = params.get("Namespace")
        self.State = params.get("State")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CLS(AbstractModel):
    """腾讯云日志服务相关参数

    """

    def __init__(self):
        r"""
        :param Enable: 是否启用
        :type Enable: bool
        :param LogSet: 日志集
        :type LogSet: str
        :param Topic: 日志主题
        :type Topic: str
        """
        self.Enable = None
        self.LogSet = None
        self.Topic = None


    def _deserialize(self, params):
        self.Enable = params.get("Enable")
        self.LogSet = params.get("LogSet")
        self.Topic = params.get("Topic")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class Cluster(AbstractModel):
    """Mesh集群信息

    """

    def __init__(self):
        r"""
        :param ClusterId: 集群Id
        :type ClusterId: str
        :param Region: 地域
        :type Region: str
        :param Role: 集群角色，取值范围：
- MASTER：控制面所在的主集群
- REMOTE：主集群管理的远端集群
        :type Role: str
        :param VpcId: 私有网络Id
        :type VpcId: str
        :param SubnetId: 子网Id
        :type SubnetId: str
        :param DisplayName: 名称，只读
        :type DisplayName: str
        :param State: 状态，只读
        :type State: str
        :param LinkedTime: 关联时间，只读
        :type LinkedTime: str
        :param Config: 集群配置
        :type Config: :class:`tencentcloud.tcm.v20210413.models.ClusterConfig`
        :param Status: 详细状态，只读
        :type Status: :class:`tencentcloud.tcm.v20210413.models.ClusterStatus`
        :param Type: 类型，取值范围：
- TKE
- EKS
        :type Type: str
        """
        self.ClusterId = None
        self.Region = None
        self.Role = None
        self.VpcId = None
        self.SubnetId = None
        self.DisplayName = None
        self.State = None
        self.LinkedTime = None
        self.Config = None
        self.Status = None
        self.Type = None


    def _deserialize(self, params):
        self.ClusterId = params.get("ClusterId")
        self.Region = params.get("Region")
        self.Role = params.get("Role")
        self.VpcId = params.get("VpcId")
        self.SubnetId = params.get("SubnetId")
        self.DisplayName = params.get("DisplayName")
        self.State = params.get("State")
        self.LinkedTime = params.get("LinkedTime")
        if params.get("Config") is not None:
            self.Config = ClusterConfig()
            self.Config._deserialize(params.get("Config"))
        if params.get("Status") is not None:
            self.Status = ClusterStatus()
            self.Status._deserialize(params.get("Status"))
        self.Type = params.get("Type")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ClusterConfig(AbstractModel):
    """集群配置

    """

    def __init__(self):
        r"""
        :param AutoInjectionNamespaceList: 自动注入SideCar的NameSpace
        :type AutoInjectionNamespaceList: list of str
        :param IngressGatewayList: Ingress配置列表
        :type IngressGatewayList: list of IngressGateway
        :param EgressGatewayList: Egress配置列表
        :type EgressGatewayList: list of EgressGateway
        :param Istiod: Istiod配置
注意：此字段可能返回 null，表示取不到有效值。
        :type Istiod: :class:`tencentcloud.tcm.v20210413.models.IstiodConfig`
        :param DeployConfig: 部署配置
        :type DeployConfig: :class:`tencentcloud.tcm.v20210413.models.DeployConfig`
        :param AutoInjectionNamespaceStateList: 自动注入命名空间状态列表
        :type AutoInjectionNamespaceStateList: list of AutoInjectionNamespaceState
        """
        self.AutoInjectionNamespaceList = None
        self.IngressGatewayList = None
        self.EgressGatewayList = None
        self.Istiod = None
        self.DeployConfig = None
        self.AutoInjectionNamespaceStateList = None


    def _deserialize(self, params):
        self.AutoInjectionNamespaceList = params.get("AutoInjectionNamespaceList")
        if params.get("IngressGatewayList") is not None:
            self.IngressGatewayList = []
            for item in params.get("IngressGatewayList"):
                obj = IngressGateway()
                obj._deserialize(item)
                self.IngressGatewayList.append(obj)
        if params.get("EgressGatewayList") is not None:
            self.EgressGatewayList = []
            for item in params.get("EgressGatewayList"):
                obj = EgressGateway()
                obj._deserialize(item)
                self.EgressGatewayList.append(obj)
        if params.get("Istiod") is not None:
            self.Istiod = IstiodConfig()
            self.Istiod._deserialize(params.get("Istiod"))
        if params.get("DeployConfig") is not None:
            self.DeployConfig = DeployConfig()
            self.DeployConfig._deserialize(params.get("DeployConfig"))
        if params.get("AutoInjectionNamespaceStateList") is not None:
            self.AutoInjectionNamespaceStateList = []
            for item in params.get("AutoInjectionNamespaceStateList"):
                obj = AutoInjectionNamespaceState()
                obj._deserialize(item)
                self.AutoInjectionNamespaceStateList.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ClusterStatus(AbstractModel):
    """集群状态

    """

    def __init__(self):
        r"""
        :param LinkState: 关联状态，取值范围：
- LINKING: 关联中
- LINKED: 已关联
- UNLINKING: 解关联中
- LINK_FAILED: 关联失败
- UNLINK_FAILED: 解关联失败
        :type LinkState: str
        :param LinkErrorDetail: 关联错误详情
注意：此字段可能返回 null，表示取不到有效值。
        :type LinkErrorDetail: str
        """
        self.LinkState = None
        self.LinkErrorDetail = None


    def _deserialize(self, params):
        self.LinkState = params.get("LinkState")
        self.LinkErrorDetail = params.get("LinkErrorDetail")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DeployConfig(AbstractModel):
    """部署配置

    """

    def __init__(self):
        r"""
        :param NodeSelectType: 部署类型，取值范围：
- SPECIFIC：专有模式
- AUTO：普通模式
        :type NodeSelectType: str
        :param Nodes: 指定的节点
        :type Nodes: list of str
        """
        self.NodeSelectType = None
        self.Nodes = None


    def _deserialize(self, params):
        self.NodeSelectType = params.get("NodeSelectType")
        self.Nodes = params.get("Nodes")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeMeshListRequest(AbstractModel):
    """DescribeMeshList请求参数结构体

    """

    def __init__(self):
        r"""
        :param Filters: 过滤条件
        :type Filters: list of Filter
        :param Limit: 分页限制
        :type Limit: int
        :param Offset: 分页偏移
        :type Offset: int
        """
        self.Filters = None
        self.Limit = None
        self.Offset = None


    def _deserialize(self, params):
        if params.get("Filters") is not None:
            self.Filters = []
            for item in params.get("Filters"):
                obj = Filter()
                obj._deserialize(item)
                self.Filters.append(obj)
        self.Limit = params.get("Limit")
        self.Offset = params.get("Offset")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeMeshListResponse(AbstractModel):
    """DescribeMeshList返回参数结构体

    """

    def __init__(self):
        r"""
        :param MeshList: 查询到的网格信息
注意：此字段可能返回 null，表示取不到有效值。
        :type MeshList: list of Mesh
        :param Total: 总数
        :type Total: int
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.MeshList = None
        self.Total = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("MeshList") is not None:
            self.MeshList = []
            for item in params.get("MeshList"):
                obj = Mesh()
                obj._deserialize(item)
                self.MeshList.append(obj)
        self.Total = params.get("Total")
        self.RequestId = params.get("RequestId")


class DescribeMeshRequest(AbstractModel):
    """DescribeMesh请求参数结构体

    """

    def __init__(self):
        r"""
        :param MeshId: 需要查询的网格 Id
        :type MeshId: str
        """
        self.MeshId = None


    def _deserialize(self, params):
        self.MeshId = params.get("MeshId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeMeshResponse(AbstractModel):
    """DescribeMesh返回参数结构体

    """

    def __init__(self):
        r"""
        :param Mesh: Mesh详细信息
        :type Mesh: :class:`tencentcloud.tcm.v20210413.models.Mesh`
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Mesh = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Mesh") is not None:
            self.Mesh = Mesh()
            self.Mesh._deserialize(params.get("Mesh"))
        self.RequestId = params.get("RequestId")


class EgressGateway(AbstractModel):
    """Egress配置

    """

    def __init__(self):
        r"""
        :param Name: Egress名称
        :type Name: str
        :param Namespace: 所在的Namespace
        :type Namespace: str
        :param Workload: 工作负载配置
        :type Workload: :class:`tencentcloud.tcm.v20210413.models.WorkloadConfig`
        """
        self.Name = None
        self.Namespace = None
        self.Workload = None


    def _deserialize(self, params):
        self.Name = params.get("Name")
        self.Namespace = params.get("Namespace")
        if params.get("Workload") is not None:
            self.Workload = WorkloadConfig()
            self.Workload._deserialize(params.get("Workload"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class Filter(AbstractModel):
    """键值对过滤器，用于条件过滤查询。例如过滤ID、名称等

    """

    def __init__(self):
        r"""
        :param Name: 需要过滤的字段。
        :type Name: str
        :param Values: 字段的过滤值。
        :type Values: list of str
        """
        self.Name = None
        self.Values = None


    def _deserialize(self, params):
        self.Name = params.get("Name")
        self.Values = params.get("Values")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GrafanaInfo(AbstractModel):
    """Grafana信息

    """

    def __init__(self):
        r"""
        :param Enabled: 是否开启
        :type Enabled: bool
        :param InternalURL: 内网地址
        :type InternalURL: str
        :param PublicURL: 公网地址
注意：此字段可能返回 null，表示取不到有效值。
        :type PublicURL: str
        :param PublicFailedReason: 公网失败原因
注意：此字段可能返回 null，表示取不到有效值。
        :type PublicFailedReason: str
        :param PublicFailedMessage: 公网失败详细信息
注意：此字段可能返回 null，表示取不到有效值。
        :type PublicFailedMessage: str
        """
        self.Enabled = None
        self.InternalURL = None
        self.PublicURL = None
        self.PublicFailedReason = None
        self.PublicFailedMessage = None


    def _deserialize(self, params):
        self.Enabled = params.get("Enabled")
        self.InternalURL = params.get("InternalURL")
        self.PublicURL = params.get("PublicURL")
        self.PublicFailedReason = params.get("PublicFailedReason")
        self.PublicFailedMessage = params.get("PublicFailedMessage")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class HorizontalPodAutoscalerSpec(AbstractModel):
    """HPA 配置

    """

    def __init__(self):
        r"""
        :param MinReplicas: 最小副本数
        :type MinReplicas: int
        :param MaxReplicas: 最大副本数
        :type MaxReplicas: int
        :param Metrics: 用于计算副本数的指标
        :type Metrics: list of MetricSpec
        """
        self.MinReplicas = None
        self.MaxReplicas = None
        self.Metrics = None


    def _deserialize(self, params):
        self.MinReplicas = params.get("MinReplicas")
        self.MaxReplicas = params.get("MaxReplicas")
        if params.get("Metrics") is not None:
            self.Metrics = []
            for item in params.get("Metrics"):
                obj = MetricSpec()
                obj._deserialize(item)
                self.Metrics.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class IngressGateway(AbstractModel):
    """IngressGateway 实例信息

    """

    def __init__(self):
        r"""
        :param Name: IngressGateway 实例名字
        :type Name: str
        :param Namespace: 命名空间
        :type Namespace: str
        :param ClusterId: 集群 ID
        :type ClusterId: str
        :param Service: Service 配置
        :type Service: :class:`tencentcloud.tcm.v20210413.models.Service`
        :param Workload: Workload 配置
        :type Workload: :class:`tencentcloud.tcm.v20210413.models.WorkloadConfig`
        :param LoadBalancer: 负载均衡配置，自动创建 CLB 时返回
注意：此字段可能返回 null，表示取不到有效值。
        :type LoadBalancer: :class:`tencentcloud.tcm.v20210413.models.LoadBalancer`
        :param Status: IngressGateway 状态信息，只读
        :type Status: :class:`tencentcloud.tcm.v20210413.models.IngressGatewayStatus`
        :param LoadBalancerId: 负载均衡实例ID，使用已有 CLB 时返回
        :type LoadBalancerId: str
        """
        self.Name = None
        self.Namespace = None
        self.ClusterId = None
        self.Service = None
        self.Workload = None
        self.LoadBalancer = None
        self.Status = None
        self.LoadBalancerId = None


    def _deserialize(self, params):
        self.Name = params.get("Name")
        self.Namespace = params.get("Namespace")
        self.ClusterId = params.get("ClusterId")
        if params.get("Service") is not None:
            self.Service = Service()
            self.Service._deserialize(params.get("Service"))
        if params.get("Workload") is not None:
            self.Workload = WorkloadConfig()
            self.Workload._deserialize(params.get("Workload"))
        if params.get("LoadBalancer") is not None:
            self.LoadBalancer = LoadBalancer()
            self.LoadBalancer._deserialize(params.get("LoadBalancer"))
        if params.get("Status") is not None:
            self.Status = IngressGatewayStatus()
            self.Status._deserialize(params.get("Status"))
        self.LoadBalancerId = params.get("LoadBalancerId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class IngressGatewayStatus(AbstractModel):
    """IngressGateway状态

    """

    def __init__(self):
        r"""
        :param LoadBalancer: 负载均衡实例状态
        :type LoadBalancer: :class:`tencentcloud.tcm.v20210413.models.LoadBalancerStatus`
        """
        self.LoadBalancer = None


    def _deserialize(self, params):
        if params.get("LoadBalancer") is not None:
            self.LoadBalancer = LoadBalancerStatus()
            self.LoadBalancer._deserialize(params.get("LoadBalancer"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class InjectConfig(AbstractModel):
    """自动注入配置

    """

    def __init__(self):
        r"""
        :param ExcludeIPRanges: 不需要进行代理的 ip 地址范围
注意：此字段可能返回 null，表示取不到有效值。
        :type ExcludeIPRanges: list of str
        :param HoldApplicationUntilProxyStarts: 是否等待sidecar启动
注意：此字段可能返回 null，表示取不到有效值。
        :type HoldApplicationUntilProxyStarts: bool
        """
        self.ExcludeIPRanges = None
        self.HoldApplicationUntilProxyStarts = None


    def _deserialize(self, params):
        self.ExcludeIPRanges = params.get("ExcludeIPRanges")
        self.HoldApplicationUntilProxyStarts = params.get("HoldApplicationUntilProxyStarts")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class IstioConfig(AbstractModel):
    """Istio配置

    """

    def __init__(self):
        r"""
        :param OutboundTrafficPolicy: 外部流量策略
        :type OutboundTrafficPolicy: str
        :param Tracing: 调用链配置
        :type Tracing: :class:`tencentcloud.tcm.v20210413.models.TracingConfig`
        :param DisablePolicyChecks: 禁用策略检查功能
注意：此字段可能返回 null，表示取不到有效值。
        :type DisablePolicyChecks: bool
        """
        self.OutboundTrafficPolicy = None
        self.Tracing = None
        self.DisablePolicyChecks = None


    def _deserialize(self, params):
        self.OutboundTrafficPolicy = params.get("OutboundTrafficPolicy")
        if params.get("Tracing") is not None:
            self.Tracing = TracingConfig()
            self.Tracing._deserialize(params.get("Tracing"))
        self.DisablePolicyChecks = params.get("DisablePolicyChecks")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class IstiodConfig(AbstractModel):
    """Istiod配置

    """

    def __init__(self):
        r"""
        :param Workload: 工作负载配置
        :type Workload: :class:`tencentcloud.tcm.v20210413.models.WorkloadConfig`
        """
        self.Workload = None


    def _deserialize(self, params):
        if params.get("Workload") is not None:
            self.Workload = WorkloadConfig()
            self.Workload._deserialize(params.get("Workload"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class LoadBalancer(AbstractModel):
    """负载均衡配置

    """

    def __init__(self):
        r"""
        :param LoadBalancerType: 负载均衡实例的网络类型：
OPEN：公网属性， INTERNAL：内网属性。
只读。
        :type LoadBalancerType: str
        :param SubnetId: 负载均衡实例所在的子网（仅对内网VPC型LB有意义），只读。
        :type SubnetId: str
        :param InternetChargeType: TRAFFIC_POSTPAID_BY_HOUR 按流量按小时后计费 ; BANDWIDTH_POSTPAID_BY_HOUR 按带宽按小时后计费;只读。
        :type InternetChargeType: str
        :param InternetMaxBandwidthOut: 最大出带宽，单位Mbps，范围支持0到2048，仅对公网属性的LB生效，默认值 10
        :type InternetMaxBandwidthOut: int
        """
        self.LoadBalancerType = None
        self.SubnetId = None
        self.InternetChargeType = None
        self.InternetMaxBandwidthOut = None


    def _deserialize(self, params):
        self.LoadBalancerType = params.get("LoadBalancerType")
        self.SubnetId = params.get("SubnetId")
        self.InternetChargeType = params.get("InternetChargeType")
        self.InternetMaxBandwidthOut = params.get("InternetMaxBandwidthOut")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class LoadBalancerStatus(AbstractModel):
    """负载均衡状态信息

    """

    def __init__(self):
        r"""
        :param LoadBalancerId: 负载均衡实例 ID
        :type LoadBalancerId: str
        :param LoadBalancerName: 负载均衡实例名字
        :type LoadBalancerName: str
        :param LoadBalancerVip: 负载均衡实例 VIP
        :type LoadBalancerVip: str
        """
        self.LoadBalancerId = None
        self.LoadBalancerName = None
        self.LoadBalancerVip = None


    def _deserialize(self, params):
        self.LoadBalancerId = params.get("LoadBalancerId")
        self.LoadBalancerName = params.get("LoadBalancerName")
        self.LoadBalancerVip = params.get("LoadBalancerVip")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class Mesh(AbstractModel):
    """Mesh信息

    """

    def __init__(self):
        r"""
        :param MeshId: Mesh实例Id
        :type MeshId: str
        :param DisplayName: Mesh名称
        :type DisplayName: str
        :param Type: Mesh类型，取值范围：
- STANDALONE：独立网格
- HOSTED：托管网格
        :type Type: str
        :param Region: 地域
        :type Region: str
        :param Version: 版本
        :type Version: str
        :param State: Mesh状态，取值范围：
- PENDING：等待中
- CREATING：创建中
- RUNNING：运行中
- ABNORMAL：异常
- UPGRADING：升级中
- CANARY_UPGRADED：升级灰度完成
- ROLLBACKING：升级回滚
- DELETING：删除中
- CREATE_FAILED：安装失败
- DELETE_FAILED：删除失败
- UPGRADE_FAILED：升级失败
- ROLLBACK_FAILED：回滚失败
        :type State: str
        :param CreatedTime: 创建时间
        :type CreatedTime: str
        :param UpdatedTime: 修改时间
注意：此字段可能返回 null，表示取不到有效值。
        :type UpdatedTime: str
        :param ClusterList: 集群列表
        :type ClusterList: list of Cluster
        :param Config: Mesh配置
        :type Config: :class:`tencentcloud.tcm.v20210413.models.MeshConfig`
        :param Status: Mesh详细状态
        :type Status: :class:`tencentcloud.tcm.v20210413.models.MeshStatus`
        """
        self.MeshId = None
        self.DisplayName = None
        self.Type = None
        self.Region = None
        self.Version = None
        self.State = None
        self.CreatedTime = None
        self.UpdatedTime = None
        self.ClusterList = None
        self.Config = None
        self.Status = None


    def _deserialize(self, params):
        self.MeshId = params.get("MeshId")
        self.DisplayName = params.get("DisplayName")
        self.Type = params.get("Type")
        self.Region = params.get("Region")
        self.Version = params.get("Version")
        self.State = params.get("State")
        self.CreatedTime = params.get("CreatedTime")
        self.UpdatedTime = params.get("UpdatedTime")
        if params.get("ClusterList") is not None:
            self.ClusterList = []
            for item in params.get("ClusterList"):
                obj = Cluster()
                obj._deserialize(item)
                self.ClusterList.append(obj)
        if params.get("Config") is not None:
            self.Config = MeshConfig()
            self.Config._deserialize(params.get("Config"))
        if params.get("Status") is not None:
            self.Status = MeshStatus()
            self.Status._deserialize(params.get("Status"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class MeshConfig(AbstractModel):
    """网格配置项

    """

    def __init__(self):
        r"""
        :param Istio: Istio配置
        :type Istio: :class:`tencentcloud.tcm.v20210413.models.IstioConfig`
        :param AccessLog: AccessLog配置
        :type AccessLog: :class:`tencentcloud.tcm.v20210413.models.AccessLogConfig`
        :param Prometheus: Prometheus配置
        :type Prometheus: :class:`tencentcloud.tcm.v20210413.models.PrometheusConfig`
        :param Inject: 自动注入配置
注意：此字段可能返回 null，表示取不到有效值。
        :type Inject: :class:`tencentcloud.tcm.v20210413.models.InjectConfig`
        """
        self.Istio = None
        self.AccessLog = None
        self.Prometheus = None
        self.Inject = None


    def _deserialize(self, params):
        if params.get("Istio") is not None:
            self.Istio = IstioConfig()
            self.Istio._deserialize(params.get("Istio"))
        if params.get("AccessLog") is not None:
            self.AccessLog = AccessLogConfig()
            self.AccessLog._deserialize(params.get("AccessLog"))
        if params.get("Prometheus") is not None:
            self.Prometheus = PrometheusConfig()
            self.Prometheus._deserialize(params.get("Prometheus"))
        if params.get("Inject") is not None:
            self.Inject = InjectConfig()
            self.Inject._deserialize(params.get("Inject"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class MeshStatus(AbstractModel):
    """Mesh当前状态

    """

    def __init__(self):
        r"""
        :param ServiceCount: 服务数量
        :type ServiceCount: int
        :param CanaryVersion: 灰度升级的版本
注意：此字段可能返回 null，表示取不到有效值。
        :type CanaryVersion: str
        :param Prometheus: Prometheus状态
注意：此字段可能返回 null，表示取不到有效值。
        :type Prometheus: list of PrometheusStatus
        :param StateMessage: 状态附带信息
注意：此字段可能返回 null，表示取不到有效值。
        :type StateMessage: str
        :param ActiveOperationList: 正在执行的异步操作
注意：此字段可能返回 null，表示取不到有效值。
        :type ActiveOperationList: list of ActiveOperation
        """
        self.ServiceCount = None
        self.CanaryVersion = None
        self.Prometheus = None
        self.StateMessage = None
        self.ActiveOperationList = None


    def _deserialize(self, params):
        self.ServiceCount = params.get("ServiceCount")
        self.CanaryVersion = params.get("CanaryVersion")
        if params.get("Prometheus") is not None:
            self.Prometheus = []
            for item in params.get("Prometheus"):
                obj = PrometheusStatus()
                obj._deserialize(item)
                self.Prometheus.append(obj)
        self.StateMessage = params.get("StateMessage")
        if params.get("ActiveOperationList") is not None:
            self.ActiveOperationList = []
            for item in params.get("ActiveOperationList"):
                obj = ActiveOperation()
                obj._deserialize(item)
                self.ActiveOperationList.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class MetricSpec(AbstractModel):
    """MetricSpec 描述如何通过指定指标进行自动扩缩容

    """

    def __init__(self):
        r"""
        :param Type: 指标来源类型，支持 Pods/Resource
        :type Type: str
        :param Pods: 使用自定义指标扩进行自动扩缩容
        :type Pods: :class:`tencentcloud.tcm.v20210413.models.PodsMetricSource`
        :param Resource: 使用资源指标扩进行自动扩缩容
        :type Resource: :class:`tencentcloud.tcm.v20210413.models.ResourceMetricSource`
        """
        self.Type = None
        self.Pods = None
        self.Resource = None


    def _deserialize(self, params):
        self.Type = params.get("Type")
        if params.get("Pods") is not None:
            self.Pods = PodsMetricSource()
            self.Pods._deserialize(params.get("Pods"))
        if params.get("Resource") is not None:
            self.Resource = ResourceMetricSource()
            self.Resource._deserialize(params.get("Resource"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class PodsMetricSource(AbstractModel):
    """PodsMetricSource 定义了如何根据特定指标进行扩缩容

    """

    def __init__(self):
        r"""
        :param MetricName: 指标名
        :type MetricName: str
        :param TargetAverageValue: 目标值
        :type TargetAverageValue: str
        """
        self.MetricName = None
        self.TargetAverageValue = None


    def _deserialize(self, params):
        self.MetricName = params.get("MetricName")
        self.TargetAverageValue = params.get("TargetAverageValue")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class PrometheusConfig(AbstractModel):
    """Prometheus 配置

    """

    def __init__(self):
        r"""
        :param VpcId: 虚拟网络Id
        :type VpcId: str
        :param SubnetId: 子网Id
        :type SubnetId: str
        :param Region: 地域
        :type Region: str
        :param InstanceId: 关联已存在实例Id，不填则默认创建
        :type InstanceId: str
        """
        self.VpcId = None
        self.SubnetId = None
        self.Region = None
        self.InstanceId = None


    def _deserialize(self, params):
        self.VpcId = params.get("VpcId")
        self.SubnetId = params.get("SubnetId")
        self.Region = params.get("Region")
        self.InstanceId = params.get("InstanceId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class PrometheusStatus(AbstractModel):
    """Prometheus状态信息

    """

    def __init__(self):
        r"""
        :param PrometheusId: Prometheus Id
        :type PrometheusId: str
        :param DisplayName: 展示名称
        :type DisplayName: str
        :param InstanceId: 实例Id
        :type InstanceId: str
        :param VpcId: 虚拟网络Id
        :type VpcId: str
        :param State: 状态
        :type State: str
        :param Region: 地区
        :type Region: str
        :param Grafana: Grafana信息
注意：此字段可能返回 null，表示取不到有效值。
        :type Grafana: :class:`tencentcloud.tcm.v20210413.models.GrafanaInfo`
        """
        self.PrometheusId = None
        self.DisplayName = None
        self.InstanceId = None
        self.VpcId = None
        self.State = None
        self.Region = None
        self.Grafana = None


    def _deserialize(self, params):
        self.PrometheusId = params.get("PrometheusId")
        self.DisplayName = params.get("DisplayName")
        self.InstanceId = params.get("InstanceId")
        self.VpcId = params.get("VpcId")
        self.State = params.get("State")
        self.Region = params.get("Region")
        if params.get("Grafana") is not None:
            self.Grafana = GrafanaInfo()
            self.Grafana._deserialize(params.get("Grafana"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class Resource(AbstractModel):
    """Resource 定义了资源类型和数量

    """

    def __init__(self):
        r"""
        :param Name: 资源类型 cpu/memory
        :type Name: str
        :param Quantity: 资源数量
        :type Quantity: str
        """
        self.Name = None
        self.Quantity = None


    def _deserialize(self, params):
        self.Name = params.get("Name")
        self.Quantity = params.get("Quantity")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ResourceMetricSource(AbstractModel):
    """ResourceMetricSource 定义了如何根据已知类型的资源指标进行扩缩容

    """

    def __init__(self):
        r"""
        :param Name: 资源名称 cpu/memory
        :type Name: str
        :param TargetAverageUtilization: 目标平均利用率
        :type TargetAverageUtilization: int
        :param TargetAverageValue: 目标平均值
        :type TargetAverageValue: str
        """
        self.Name = None
        self.TargetAverageUtilization = None
        self.TargetAverageValue = None


    def _deserialize(self, params):
        self.Name = params.get("Name")
        self.TargetAverageUtilization = params.get("TargetAverageUtilization")
        self.TargetAverageValue = params.get("TargetAverageValue")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ResourceRequirements(AbstractModel):
    """ResourceRequirements 描述了计算资源需求。

    """

    def __init__(self):
        r"""
        :param Limits: Limits 描述了允许的最大计算资源量。
        :type Limits: list of Resource
        :param Requests: Requests 描述所需的最小计算资源量。
        :type Requests: list of Resource
        """
        self.Limits = None
        self.Requests = None


    def _deserialize(self, params):
        if params.get("Limits") is not None:
            self.Limits = []
            for item in params.get("Limits"):
                obj = Resource()
                obj._deserialize(item)
                self.Limits.append(obj)
        if params.get("Requests") is not None:
            self.Requests = []
            for item in params.get("Requests"):
                obj = Resource()
                obj._deserialize(item)
                self.Requests.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class SelectedItems(AbstractModel):
    """选中的项目

    """

    def __init__(self):
        r"""
        :param Namespace: 命名空间
        :type Namespace: str
        :param ClusterName: 集群名称
        :type ClusterName: str
        :param ItemName: 选中项目名字
        :type ItemName: str
        :param Gateways: ingress gw的名称列表
        :type Gateways: list of str
        """
        self.Namespace = None
        self.ClusterName = None
        self.ItemName = None
        self.Gateways = None


    def _deserialize(self, params):
        self.Namespace = params.get("Namespace")
        self.ClusterName = params.get("ClusterName")
        self.ItemName = params.get("ItemName")
        self.Gateways = params.get("Gateways")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class SelectedRange(AbstractModel):
    """被选中的范围

    """

    def __init__(self):
        r"""
        :param Items: 选中的项目详细内容
        :type Items: list of SelectedItems
        :param All: 是否全选
        :type All: bool
        """
        self.Items = None
        self.All = None


    def _deserialize(self, params):
        if params.get("Items") is not None:
            self.Items = []
            for item in params.get("Items"):
                obj = SelectedItems()
                obj._deserialize(item)
                self.Items.append(obj)
        self.All = params.get("All")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class Service(AbstractModel):
    """Service信息

    """

    def __init__(self):
        r"""
        :param Type: ClusterIP/NodePort/LoadBalancer
        :type Type: str
        :param CLBDirectAccess: 是否开启LB直通Pod
        :type CLBDirectAccess: bool
        :param ExternalTrafficPolicy: 服务是否希望将外部流量路由到节点本地或集群范围的端点。 有两个可用选项：Cluster（默认）和 Local。Cluster 隐藏了客户端源 IP，可能导致第二跳到另一个节点；Local 保留客户端源 IP 并避免 LoadBalancer 和 NodePort 类型服务的第二跳。
        :type ExternalTrafficPolicy: str
        """
        self.Type = None
        self.CLBDirectAccess = None
        self.ExternalTrafficPolicy = None


    def _deserialize(self, params):
        self.Type = params.get("Type")
        self.CLBDirectAccess = params.get("CLBDirectAccess")
        self.ExternalTrafficPolicy = params.get("ExternalTrafficPolicy")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class TracingConfig(AbstractModel):
    """调用链配置

    """

    def __init__(self):
        r"""
        :param Sampling: 调用链采样率，百分比
        :type Sampling: float
        """
        self.Sampling = None


    def _deserialize(self, params):
        self.Sampling = params.get("Sampling")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class WorkloadConfig(AbstractModel):
    """工作负载配置

    """

    def __init__(self):
        r"""
        :param Replicas: 工作副本数
        :type Replicas: int
        :param Resources: 资源限制
        :type Resources: :class:`tencentcloud.tcm.v20210413.models.ResourceRequirements`
        :param HorizontalPodAutoscaler: HPA策略
        :type HorizontalPodAutoscaler: :class:`tencentcloud.tcm.v20210413.models.HorizontalPodAutoscalerSpec`
        :param SelectedNodeList: 部署到指定节点
        :type SelectedNodeList: list of str
        """
        self.Replicas = None
        self.Resources = None
        self.HorizontalPodAutoscaler = None
        self.SelectedNodeList = None


    def _deserialize(self, params):
        self.Replicas = params.get("Replicas")
        if params.get("Resources") is not None:
            self.Resources = ResourceRequirements()
            self.Resources._deserialize(params.get("Resources"))
        if params.get("HorizontalPodAutoscaler") is not None:
            self.HorizontalPodAutoscaler = HorizontalPodAutoscalerSpec()
            self.HorizontalPodAutoscaler._deserialize(params.get("HorizontalPodAutoscaler"))
        self.SelectedNodeList = params.get("SelectedNodeList")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.tiia.v20190529 import models


class TiiaClient(AbstractClient):
    _apiVersion = '2019-05-29'
    _endpoint = 'tiia.tencentcloudapi.com'
    _service = 'tiia'


    def AssessQuality(self, request):
        """评估输入图片在视觉上的质量，从多个方面评估，并同时给出综合的、客观的清晰度评分，和主观的美观度评分。
        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for AssessQuality.
        :type request: :class:`tencentcloud.tiia.v20190529.models.AssessQualityRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.AssessQualityResponse`

        """
        try:
            params = request._serialize()
            body = self.call("AssessQuality", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.AssessQualityResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateGroup(self, request):
        """用于创建一个空的图片库，如果图片库已存在则返回错误。

        :param request: Request instance for CreateGroup.
        :type request: :class:`tencentcloud.tiia.v20190529.models.CreateGroupRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.CreateGroupResponse`

        """
        try:
            params = request._serialize()
            body = self.call("CreateGroup", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateGroupResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateImage(self, request):
        """创建图片，并添加对应图片的自定义信息。

        :param request: Request instance for CreateImage.
        :type request: :class:`tencentcloud.tiia.v20190529.models.CreateImageRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.CreateImageResponse`

        """
        try:
            params = request._serialize()
            body = self.call("CreateImage", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateImageResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CropImage(self, request):
        """根据输入的裁剪比例，智能判断一张图片的最佳裁剪区域，确保原图的主体区域不受影响。

        可以自动裁剪图片，适应不同平台、设备的展示要求，避免简单拉伸带来的变形。
        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for CropImage.
        :type request: :class:`tencentcloud.tiia.v20190529.models.CropImageRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.CropImageResponse`

        """
        try:
            params = request._serialize()
            body = self.call("CropImage", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CropImageResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DeleteImages(self, request):
        """删除图片。

        :param request: Request instance for DeleteImages.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DeleteImagesRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DeleteImagesResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DeleteImages", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DeleteImagesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeGroups(self, request):
        """查询所有的图库信息。

        :param request: Request instance for DescribeGroups.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DescribeGroupsRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DescribeGroupsResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeGroups", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeGroupsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeImages(self, request):
        """获取指定图片库中的图片列表。

        :param request: Request instance for DescribeImages.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DescribeImagesRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DescribeImagesResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeImages", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeImagesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectCelebrity(self, request):
        """传入一张图片，可以识别图片中包含的人物是否为公众人物，如果是，输出人物的姓名、基本信息、脸部坐标。

        支持识别一张图片中存在的多个人脸，针对每个人脸，会给出与之最相似的公众人物。
        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectCelebrity.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectCelebrityRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectCelebrityResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DetectCelebrity", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectCelebrityResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectDisgust(self, request):
        """输入一张图片，返回AI针对一张图片是否是恶心的一系列判断值。

        通过恶心图片识别, 可以判断一张图片是否令人恶心, 同时给出它属于的潜在类别, 让您能够过滤掉使人不愉快的图片。
        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectDisgust.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectDisgustRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectDisgustResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DetectDisgust", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectDisgustResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectLabel(self, request):
        """图像标签利用深度学习技术、海量训练数据，可以对图片进行智能分类、物体识别等。

        目前支持8个大类、六十多个子类、数千个标签。涵盖各种日常场景、动植物、物品、美食、卡证等。具体分类请见[图像分析常见问题功能与限制相关](https://cloud.tencent.com/document/product/865/39164)。

        图像标签提供四个版本供选择：

        • 摄像头版：针对搜索、手机摄像头照片进行优化，涵盖大量卡证、日常物品、二维码条形码。

        • 相册版：针对手机相册、网盘进行优化，去除相册和网盘中不常见的标签，针对相册常见图片类型（人像、日常活动、日常物品等）识别效果更好。

        • 网络版：针对网络图片进行优化，涵盖标签更多，满足长尾识别需求。

        • 新闻版：针对新闻、资讯、广电等行业进行优化，增加定制识别，支持万级图像标签。

        每个产品的图像类型都有独特性，建议在接入初期，对四个版本进行对比评估后选择合适的版本使用。

        为了方便使用、减少图片传输次数，图像标签包装成多合一接口，实际上是多个服务。

        图像标签按照服务的实际使用数量进行收费。例如一张图片同时调用相册版、摄像头版两个服务，那么此次调用按照两次计费。
        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectLabel.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectLabelRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectLabelResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DetectLabel", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectLabelResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectLabelBeta(self, request):
        """图像标签测试接口

        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectLabelBeta.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectLabelBetaRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectLabelBetaResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DetectLabelBeta", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectLabelBetaResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectMisbehavior(self, request):
        """可以识别输入的图片中是否包含不良行为，例如打架斗殴、赌博、抽烟等，可以应用于广告图、直播截图、短视频截图等审核，减少不良行为对平台内容质量的影响，维护健康向上的互联网环境。
        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectMisbehavior.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectMisbehaviorRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectMisbehaviorResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DetectMisbehavior", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectMisbehaviorResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectProduct(self, request):
        """本接口支持识别图片中包含的商品，能够输出商品的品类名称、类别，还可以输出商品在图片中的位置。支持一张图片多个商品的识别。
        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectProduct.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectProductRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectProductResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DetectProduct", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectProductResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectProductBeta(self, request):
        """商品识别-微信识物版，基于人工智能技术、海量训练图片、亿级商品库，可以实现全覆盖、细粒度、高准确率的商品识别和商品推荐功能。
        本服务可以识别出图片中的主体位置、主体商品类型，覆盖亿级SKU，输出具体商品的价格、型号等详细信息。
        客户无需自建商品库，即可快速实现商品识别、拍照搜商品等功能。

        目前“商品识别-微信识物版”为内测服务，需要申请、开通后方可使用。请在[服务开通申请表](https://cloud.tencent.com/apply/p/y1q2mnf0vdl) 中填写详细信息和需求，如果通过审核，我们将会在2个工作日内与您联系，并开通服务。
        内测期间，本服务免费提供最高2QPS，收费模式和标准会在正式版上线前通过站内信、短信通知客户。如果需要提升并发，请与我们联系洽谈。

        注意：本文档为内测版本，仅适用于功能体验和测试，正式业务接入请等待正式版。正式版的输入、输出可能会与内测版存在少量差异。
        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectProductBeta.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectProductBetaRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectProductBetaResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DetectProductBeta", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectProductBetaResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def EnhanceImage(self, request):
        """传入一张图片，输出清晰度提升后的图片。

        可以消除图片有损压缩导致的噪声，和使用滤镜、拍摄失焦导致的模糊。让图片的边缘和细节更加清晰自然。
        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for EnhanceImage.
        :type request: :class:`tencentcloud.tiia.v20190529.models.EnhanceImageRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.EnhanceImageResponse`

        """
        try:
            params = request._serialize()
            body = self.call("EnhanceImage", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.EnhanceImageResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def RecognizeCar(self, request):
        """腾讯云车辆属性识别可对汽车车身及车辆属性进行检测与识别，目前支持11种车身颜色、20多种车型、300多种品牌、4000多种车系+年款的识别，同时支持对车辆的位置进行检测。如果图片中存在多辆车，会分别输出每辆车的车型和坐标。
        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for RecognizeCar.
        :type request: :class:`tencentcloud.tiia.v20190529.models.RecognizeCarRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.RecognizeCarResponse`

        """
        try:
            params = request._serialize()
            body = self.call("RecognizeCar", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.RecognizeCarResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def SearchImage(self, request):
        """本接口用于对一张待识别的商品图片，在指定图片库中检索出最相似的图片列表。

        :param request: Request instance for SearchImage.
        :type request: :class:`tencentcloud.tiia.v20190529.models.SearchImageRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.SearchImageResponse`

        """
        try:
            params = request._serialize()
            body = self.call("SearchImage", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.SearchImageResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class AgePortrait(AbstractModel):
    """用户年龄画像

    """

    def __init__(self):
        r"""
        :param AgeRange: 年龄区间
        :type AgeRange: str
        :param Percent: 百分比
        :type Percent: float
        """
        self.AgeRange = None
        self.Percent = None


    def _deserialize(self, params):
        self.AgeRange = params.get("AgeRange")
        self.Percent = params.get("Percent")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class AgePortraitInfo(AbstractModel):
    """用户年龄画像元素数组

    """

    def __init__(self):
        r"""
        :param PortraitSet: 用户年龄画像数组
        :type PortraitSet: list of AgePortrait
        """
        self.PortraitSet = None


    def _deserialize(self, params):
        if params.get("PortraitSet") is not None:
            self.PortraitSet = []
            for item in params.get("PortraitSet"):
                obj = AgePortrait()
                obj._deserialize(item)
                self.PortraitSet.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class BrandReportArticle(AbstractModel):
    """文章信息

    """

    def __init__(self):
        r"""
        :param Title: 文章标题
        :type Title: str
        :param Url: 文章url地址
        :type Url: str
        :param FromSite: 文章来源
        :type FromSite: str
        :param PubTime: 文章发表日期
        :type PubTime: str
        :param Flag: 文章标识
        :type Flag: int
        :param Hot: 文章热度值
        :type Hot: int
        :param Level: 文章来源等级
        :type Level: int
        :param Abstract: 文章摘要
        :type Abstract: str
        :param ArticleId: 文章ID
        :type ArticleId: str
        """
        self.Title = None
        self.Url = None
        self.FromSite = None
        self.PubTime = None
        self.Flag = None
        self.Hot = None
        self.Level = None
        self.Abstract = None
        self.ArticleId = None


    def _deserialize(self, params):
        self.Title = params.get("Title")
        self.Url = params.get("Url")
        self.FromSite = params.get("FromSite")
        self.PubTime = params.get("PubTime")
        self.Flag = params.get("Flag")
        self.Hot = params.get("Hot")
        self.Level = params.get("Level")
        self.Abstract = params.get("Abstract")
        self.ArticleId = params.get("ArticleId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class Comment(AbstractModel):
    """用户好评差评个数信息

    """

    def __init__(self):
        r"""
        :param Date: 评论的日期
        :type Date: str
        :param NegCommentCount: 差评的个数
        :type NegCommentCount: int
        :param PosCommentCount: 好评的个数
        :type PosCommentCount: int
        """
        self.Date = None
        self.NegCommentCount = None
        self.PosCommentCount = None


    def _deserialize(self, params):
        self.Date = params.get("Date")
        self.NegCommentCount = params.get("NegCommentCount")
        self.PosCommentCount = params.get("PosCommentCount")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CommentInfo(AbstractModel):
    """用户评论内容类型

    """

    def __init__(self):
        r"""
        :param Comment: 用户评论内容
        :type Comment: str
        :param Date: 评论的时间
        :type Date: str
        """
        self.Comment = None
        self.Date = None


    def _deserialize(self, params):
        self.Comment = params.get("Comment")
        self.Date = params.get("Date")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DateCount(AbstractModel):
    """按日期的统计数据

    """

    def __init__(self):
        r"""
        :param Date: 统计日期
        :type Date: str
        :param Count: 统计值
        :type Count: int
        """
        self.Date = None
        self.Count = None


    def _deserialize(self, params):
        self.Date = params.get("Date")
        self.Count = params.get("Count")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeBrandCommentCountRequest(AbstractModel):
    """DescribeBrandCommentCount请求参数结构体

    """

    def __init__(self):
        r"""
        :param BrandId: 品牌ID
        :type BrandId: str
        :param StartDate: 查询开始日期
        :type StartDate: str
        :param EndDate: 查询结束日期
        :type EndDate: str
        """
        self.BrandId = None
        self.StartDate = None
        self.EndDate = None


    def _deserialize(self, params):
        self.BrandId = params.get("BrandId")
        self.StartDate = params.get("StartDate")
        self.EndDate = params.get("EndDate")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeBrandCommentCountResponse(AbstractModel):
    """DescribeBrandCommentCount返回参数结构体

    """

    def __init__(self):
        r"""
        :param CommentSet: 按天统计好评/差评数
        :type CommentSet: list of Comment
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.CommentSet = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("CommentSet") is not None:
            self.CommentSet = []
            for item in params.get("CommentSet"):
                obj = Comment()
                obj._deserialize(item)
                self.CommentSet.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeBrandExposureRequest(AbstractModel):
    """DescribeBrandExposure请求参数结构体

    """

    def __init__(self):
        r"""
        :param BrandId: 品牌ID
        :type BrandId: str
        :param StartDate: 查询开始时间
        :type StartDate: str
        :param EndDate: 查询结束时间
        :type EndDate: str
        """
        self.BrandId = None
        self.StartDate = None
        self.EndDate = None


    def _deserialize(self, params):
        self.BrandId = params.get("BrandId")
        self.StartDate = params.get("StartDate")
        self.EndDate = params.get("EndDate")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeBrandExposureResponse(AbstractModel):
    """DescribeBrandExposure返回参数结构体

    """

    def __init__(self):
        r"""
        :param TotalCount: 累计曝光量
        :type TotalCount: int
        :param DateCountSet: 按天计算的统计数据
        :type DateCountSet: list of DateCount
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.TotalCount = None
        self.DateCountSet = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalCount = params.get("TotalCount")
        if params.get("DateCountSet") is not None:
            self.DateCountSet = []
            for item in params.get("DateCountSet"):
                obj = DateCount()
                obj._deserialize(item)
                self.DateCountSet.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeBrandMediaReportRequest(AbstractModel):
    """DescribeBrandMediaReport请求参数结构体

    """

    def __init__(self):
        r"""
        :param BrandId: 品牌ID
        :type BrandId: str
        :param StartDate: 查询开始时间
        :type StartDate: str
        :param EndDate: 查询结束时间
        :type EndDate: str
        """
        self.BrandId = None
        self.StartDate = None
        self.EndDate = None


    def _deserialize(self, params):
        self.BrandId = params.get("BrandId")
        self.StartDate = params.get("StartDate")
        self.EndDate = params.get("EndDate")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeBrandMediaReportResponse(AbstractModel):
    """DescribeBrandMediaReport返回参数结构体

    """

    def __init__(self):
        r"""
        :param TotalCount: 查询范围内文章总数
        :type TotalCount: int
        :param DateCountSet: 按天计算的每天文章数
        :type DateCountSet: list of DateCount
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.TotalCount = None
        self.DateCountSet = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalCount = params.get("TotalCount")
        if params.get("DateCountSet") is not None:
            self.DateCountSet = []
            for item in params.get("DateCountSet"):
                obj = DateCount()
                obj._deserialize(item)
                self.DateCountSet.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeBrandNegCommentsRequest(AbstractModel):
    """DescribeBrandNegComments请求参数结构体

    """

    def __init__(self):
        r"""
        :param BrandId: 品牌ID
        :type BrandId: str
        :param StartDate: 查询开始时间
        :type StartDate: str
        :param EndDate: 查询结束时间
        :type EndDate: str
        :param Limit: 查询条数上限，默认20
        :type Limit: int
        :param Offset: 查询偏移，默认从0开始
        :type Offset: int
        """
        self.BrandId = None
        self.StartDate = None
        self.EndDate = None
        self.Limit = None
        self.Offset = None


    def _deserialize(self, params):
        self.BrandId = params.get("BrandId")
        self.StartDate = params.get("StartDate")
        self.EndDate = params.get("EndDate")
        self.Limit = params.get("Limit")
        self.Offset = params.get("Offset")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeBrandNegCommentsResponse(AbstractModel):
    """DescribeBrandNegComments返回参数结构体

    """

    def __init__(self):
        r"""
        :param BrandCommentSet: 评论列表
        :type BrandCommentSet: list of CommentInfo
        :param TotalComments: 总的差评个数
        :type TotalComments: int
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.BrandCommentSet = None
        self.TotalComments = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("BrandCommentSet") is not None:
            self.BrandCommentSet = []
            for item in params.get("BrandCommentSet"):
                obj = CommentInfo()
                obj._deserialize(item)
                self.BrandCommentSet.append(obj)
        self.TotalComments = params.get("TotalComments")
        self.RequestId = params.get("RequestId")


class DescribeBrandPosCommentsRequest(AbstractModel):
    """DescribeBrandPosComments请求参数结构体

    """

    def __init__(self):
        r"""
        :param BrandId: 品牌ID
        :type BrandId: str
        :param StartDate: 查询开始时间
        :type StartDate: str
        :param EndDate: 查询结束时间
        :type EndDate: str
        :param Limit: 查询条数上限，默认20
        :type Limit: int
        :param Offset: 查询偏移，从0开始
        :type Offset: int
        """
        self.BrandId = None
        self.StartDate = None
        self.EndDate = None
        self.Limit = None
        self.Offset = None


    def _deserialize(self, params):
        self.BrandId = params.get("BrandId")
        self.StartDate = params.get("StartDate")
        self.EndDate = params.get("EndDate")
        self.Limit = params.get("Limit")
        self.Offset = params.get("Offset")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeBrandPosCommentsResponse(AbstractModel):
    """DescribeBrandPosComments返回参数结构体

    """

    def __init__(self):
        r"""
        :param BrandCommentSet: 评论列表
        :type BrandCommentSet: list of CommentInfo
        :param TotalComments: 总的好评个数
        :type TotalComments: int
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.BrandCommentSet = None
        self.TotalComments = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("BrandCommentSet") is not None:
            self.BrandCommentSet = []
            for item in params.get("BrandCommentSet"):
                obj = CommentInfo()
                obj._deserialize(item)
                self.BrandCommentSet.append(obj)
        self.TotalComments = params.get("TotalComments")
        self.RequestId = params.get("RequestId")


class DescribeBrandSocialOpinionRequest(AbstractModel):
    """DescribeBrandSocialOpinion请求参数结构体

    """

    def __init__(self):
        r"""
        :param BrandId: 品牌ID
        :type BrandId: str
        :param StartDate: 检索开始时间
        :type StartDate: str
        :param EndDate: 检索结束时间
        :type EndDate: str
        :param Offset: 查询偏移，默认从0开始
        :type Offset: int
        :param Limit: 查询条数上限，默认20
        :type Limit: int
        :param ShowList: 列表显示标记，若为true，则返回文章列表详情
        :type ShowList: bool
        """
        self.BrandId = None
        self.StartDate = None
        self.EndDate = None
        self.Offset = None
        self.Limit = None
        self.ShowList = None


    def _deserialize(self, params):
        self.BrandId = params.get("BrandId")
        self.StartDate = params.get("StartDate")
        self.EndDate = params.get("EndDate")
        self.Offset = params.get("Offset")
        self.Limit = params.get("Limit")
        self.ShowList = params.get("ShowList")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeBrandSocialOpinionResponse(AbstractModel):
    """DescribeBrandSocialOpinion返回参数结构体

    """

    def __init__(self):
        r"""
        :param ArticleCount: 文章总数
        :type ArticleCount: int
        :param FromCount: 来源统计总数
        :type FromCount: int
        :param AdverseCount: 疑似负面报道总数
        :type AdverseCount: int
        :param ArticleSet: 文章列表详情
        :type ArticleSet: list of BrandReportArticle
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.ArticleCount = None
        self.FromCount = None
        self.AdverseCount = None
        self.ArticleSet = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ArticleCount = params.get("ArticleCount")
        self.FromCount = params.get("FromCount")
        self.AdverseCount = params.get("AdverseCount")
        if params.get("ArticleSet") is not None:
            self.ArticleSet = []
            for item in params.get("ArticleSet"):
                obj = BrandReportArticle()
                obj._deserialize(item)
                self.ArticleSet.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeBrandSocialReportRequest(AbstractModel):
    """DescribeBrandSocialReport请求参数结构体

    """

    def __init__(self):
        r"""
        :param BrandId: 品牌ID
        :type BrandId: str
        :param StartDate: 查询开始时间
        :type StartDate: str
        :param EndDate: 查询结束时间
        :type EndDate: str
        """
        self.BrandId = None
        self.StartDate = None
        self.EndDate = None


    def _deserialize(self, params):
        self.BrandId = params.get("BrandId")
        self.StartDate = params.get("StartDate")
        self.EndDate = params.get("EndDate")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeBrandSocialReportResponse(AbstractModel):
    """DescribeBrandSocialReport返回参数结构体

    """

    def __init__(self):
        r"""
        :param TotalCount: 累计统计数据
        :type TotalCount: int
        :param DateCountSet: 按天计算的统计数据
        :type DateCountSet: list of DateCount
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.TotalCount = None
        self.DateCountSet = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalCount = params.get("TotalCount")
        if params.get("DateCountSet") is not None:
            self.DateCountSet = []
            for item in params.get("DateCountSet"):
                obj = DateCount()
                obj._deserialize(item)
                self.DateCountSet.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeIndustryNewsRequest(AbstractModel):
    """DescribeIndustryNews请求参数结构体

    """

    def __init__(self):
        r"""
        :param IndustryId: 行业ID
        :type IndustryId: str
        :param StartDate: 查询开始时间
        :type StartDate: str
        :param EndDate: 查询结束时间
        :type EndDate: str
        :param ShowList: 是否显示列表，若为 true，则返回文章列表
        :type ShowList: bool
        :param Offset: 查询偏移，默认从0开始
        :type Offset: int
        :param Limit: 查询条数上限，默认20
        :type Limit: int
        """
        self.IndustryId = None
        self.StartDate = None
        self.EndDate = None
        self.ShowList = None
        self.Offset = None
        self.Limit = None


    def _deserialize(self, params):
        self.IndustryId = params.get("IndustryId")
        self.StartDate = params.get("StartDate")
        self.EndDate = params.get("EndDate")
        self.ShowList = params.get("ShowList")
        self.Offset = params.get("Offset")
        self.Limit = params.get("Limit")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeIndustryNewsResponse(AbstractModel):
    """DescribeIndustryNews返回参数结构体

    """

    def __init__(self):
        r"""
        :param NewsCount: 总计文章数量
        :type NewsCount: int
        :param FromCount: 总计来源数量
        :type FromCount: int
        :param AdverseCount: 总计疑似负面数量
        :type AdverseCount: int
        :param NewsSet: 文章列表
        :type NewsSet: list of IndustryNews
        :param DateCountSet: 按天统计的数量列表
        :type DateCountSet: list of DateCount
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.NewsCount = None
        self.FromCount = None
        self.AdverseCount = None
        self.NewsSet = None
        self.DateCountSet = None
        self.RequestId = None


    def _deserialize(self, params):
        self.NewsCount = params.get("NewsCount")
        self.FromCount = params.get("FromCount")
        self.AdverseCount = params.get("AdverseCount")
        if params.get("NewsSet") is not None:
            self.NewsSet = []
            for item in params.get("NewsSet"):
                obj = IndustryNews()
                obj._deserialize(item)
                self.NewsSet.append(obj)
        if params.get("DateCountSet") is not None:
            self.DateCountSet = []
            for item in params.get("DateCountSet"):
                obj = DateCount()
                obj._deserialize(item)
                self.DateCountSet.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeUserPortraitRequest(AbstractModel):
    """DescribeUserPortrait请求参数结构体

    """

    def __init__(self):
        r"""
        :param BrandId: 品牌ID
        :type BrandId: str
        """
        self.BrandId = None


    def _deserialize(self, params):
        self.BrandId = params.get("BrandId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeUserPortraitResponse(AbstractModel):
    """DescribeUserPortrait返回参数结构体

    """

    def __init__(self):
        r"""
        :param Age: 年龄画像
        :type Age: :class:`tencentcloud.tbm.v20180129.models.AgePortraitInfo`
        :param Gender: 性别画像
        :type Gender: :class:`tencentcloud.tbm.v20180129.models.GenderPortraitInfo`
        :param Province: 省份画像
        :type Province: :class:`tencentcloud.tbm.v20180129.models.ProvincePortraitInfo`
        :param Movie: 电影喜好画像
        :type Movie: :class:`tencentcloud.tbm.v20180129.models.MoviePortraitInfo`
        :param Star: 明星喜好画像
        :type Star: :class:`tencentcloud.tbm.v20180129.models.StarPortraitInfo`
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Age = None
        self.Gender = None
        self.Province = None
        self.Movie = None
        self.Star = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Age") is not None:
            self.Age = AgePortraitInfo()
            self.Age._deserialize(params.get("Age"))
        if params.get("Gender") is not None:
            self.Gender = GenderPortraitInfo()
            self.Gender._deserialize(params.get("Gender"))
        if params.get("Province") is not None:
            self.Province = ProvincePortraitInfo()
            self.Province._deserialize(params.get("Province"))
        if params.get("Movie") is not None:
            self.Movie = MoviePortraitInfo()
            self.Movie._deserialize(params.get("Movie"))
        if params.get("Star") is not None:
            self.Star = StarPortraitInfo()
            self.Star._deserialize(params.get("Star"))
        self.RequestId = params.get("RequestId")


class GenderPortrait(AbstractModel):
    """性别画像元素

    """

    def __init__(self):
        r"""
        :param Gender: 性别
        :type Gender: str
        :param Percent: 百分比
        :type Percent: int
        """
        self.Gender = None
        self.Percent = None


    def _deserialize(self, params):
        self.Gender = params.get("Gender")
        self.Percent = params.get("Percent")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GenderPortraitInfo(AbstractModel):
    """用户性别画像元素数组

    """

    def __init__(self):
        r"""
        :param PortraitSet: 用户性别画像数组
        :type PortraitSet: list of GenderPortrait
        """
        self.PortraitSet = None


    def _deserialize(self, params):
        if params.get("PortraitSet") is not None:
            self.PortraitSet = []
            for item in params.get("PortraitSet"):
                obj = GenderPortrait()
                obj._deserialize(item)
                self.PortraitSet.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class IndustryNews(AbstractModel):
    """行业报道新闻

    """

    def __init__(self):
        r"""
        :param IndustryId: 行业报道ID
        :type IndustryId: str
        :param PubTime: 报道发表时间
        :type PubTime: str
        :param FromSite: 报道来源
        :type FromSite: str
        :param Title: 报道标题
        :type Title: str
        :param Url: 报道来源url
        :type Url: str
        :param Level: 报道来源等级
        :type Level: int
        :param Hot: 热度值
        :type Hot: int
        :param Flag: 报道标识
        :type Flag: int
        :param Abstract: 报道摘要
        :type Abstract: str
        """
        self.IndustryId = None
        self.PubTime = None
        self.FromSite = None
        self.Title = None
        self.Url = None
        self.Level = None
        self.Hot = None
        self.Flag = None
        self.Abstract = None


    def _deserialize(self, params):
        self.IndustryId = params.get("IndustryId")
        self.PubTime = params.get("PubTime")
        self.FromSite = params.get("FromSite")
        self.Title = params.get("Title")
        self.Url = params.get("Url")
        self.Level = params.get("Level")
        self.Hot = params.get("Hot")
        self.Flag = params.get("Flag")
        self.Abstract = params.get("Abstract")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class MoviePortrait(AbstractModel):
    """电影喜好画像元素

    """

    def __init__(self):
        r"""
        :param Name: 电影名称
        :type Name: str
        :param Percent: 百分比
        :type Percent: float
        """
        self.Name = None
        self.Percent = None


    def _deserialize(self, params):
        self.Name = params.get("Name")
        self.Percent = params.get("Percent")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class MoviePortraitInfo(AbstractModel):
    """用户喜好电影画像元素数组

    """

    def __init__(self):
        r"""
        :param PortraitSet: 用户喜好电影画像数组
        :type PortraitSet: list of MoviePortrait
        """
        self.PortraitSet = None


    def _deserialize(self, params):
        if params.get("PortraitSet") is not None:
            self.PortraitSet = []
            for item in params.get("PortraitSet"):
                obj = MoviePortrait()
                obj._deserialize(item)
                self.PortraitSet.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ProvincePortrait(AbstractModel):
    """省份画像元素

    """

    def __init__(self):
        r"""
        :param Province: 省份名称
        :type Province: str
        :param Percent: 百分比
        :type Percent: float
        """
        self.Province = None
        self.Percent = None


    def _deserialize(self, params):
        self.Province = params.get("Province")
        self.Percent = params.get("Percent")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ProvincePortraitInfo(AbstractModel):
    """用户省份画像元素数组

    """

    def __init__(self):
        r"""
        :param PortraitSet: 用户省份画像数组
        :type PortraitSet: list of ProvincePortrait
        """
        self.PortraitSet = None


    def _deserialize(self, params):
        if params.get("PortraitSet") is not None:
            self.PortraitSet = []
            for item in params.get("PortraitSet"):
                obj = ProvincePortrait()
                obj._deserialize(item)
                self.PortraitSet.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class StarPortrait(AbstractModel):
    """明星喜好画像元素

    """

    def __init__(self):
        r"""
        :param Name: 喜欢的明星名字
        :type Name: str
        :param Percent: 百分比
        :type Percent: float
        """
        self.Name = None
        self.Percent = None


    def _deserialize(self, params):
        self.Name = params.get("Name")
        self.Percent = params.get("Percent")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class StarPortraitInfo(AbstractModel):
    """用户喜好的明星画像元素数组

    """

    def __init__(self):
        r"""
        :param PortraitSet: 用户喜好的明星画像数组
        :type PortraitSet: list of StarPortrait
        """
        self.PortraitSet = None


    def _deserialize(self, params):
        if params.get("PortraitSet") is not None:
            self.PortraitSet = []
            for item in params.get("PortraitSet"):
                obj = StarPortrait()
                obj._deserialize(item)
                self.PortraitSet.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        